
// FileWriter.h
// provides functionalities for writing ascii or unicode based file
// provides functions to open, write and file related other functions

#ifndef __ULE_FILE_WRITER_H__
#define __ULE_FILE_WRITER_H__

#include <fstream>
#include <string>
using namespace std;

#include "utility.h"


class FileWriter {

public:
	enum CODE {UNI, ASCII};

private:

	// data members
	fstream _ofsWriter;
	// use of ofstream object ceased because the seekp() function requires 
	// ios::ate option enabled but there is some problem with ios::ate 
	// in <fstream> header file (i.e. truncates privous contents). Therefore,
	// fstream is being used instead with ios::in|ios::out; and with ios::ate,
	// if open in append mode.
	bool _bFileOpened;	// is file opened
	CODE _characterSet;	// unicode or ascii
	bool _bApp;			// is file opened in append mode

public:

	// interface
	FileWriter ();
	~FileWriter ();
	bool Open (const char* cFileNamePtr, CODE charSet = FileWriter::ASCII,
		bool bAppend = false);
	bool DoesExist (const char* cFileNamePtr);
	bool Write (string strBuffer);
	bool Write (wstring strBuffer);
	bool Write (char * strBuffer, int size);
	bool Write (wchar_t * buf, int n);
	void Seekp (long pos, short dir);
	void Flush ();
	long Tellp ();
	void Close ();

};

#endif // __ULE_FILE_WRITER_H__
